using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.IO;

namespace SimpleUploadBar
{
	/// <summary>
	/// Summary description for Upload.
	/// </summary>
	public class Upload : System.Web.UI.Page
	{
		protected System.Web.UI.HtmlControls.HtmlInputFile file1;
		protected System.Web.UI.HtmlControls.HtmlInputButton btnUpload;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			// Register all the necessary client side code
			RegisterUploadScript();
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.btnUpload.ServerClick += new System.EventHandler(this.btnUpload_ServerClick);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		/// <summary>
		/// Registers the script that causes this page to pop up the
		/// upload page, passing it a GUID to be used as an identifier for the
		/// upload. This script also reloads the currnet page with the upload ID
		/// in the query string. This is so that the intercept routine can grab
		/// the ID from the local request scope.
		/// </summary>
		/// <remarks>The uploader must be in a separate window to the page
		/// from which the files are being submitted. This is because browsers
		/// such as <i>Microsoft Internet Explorer</i> prevent page updates
		/// during uploading.</remarks>
		private void RegisterUploadScript()
		{
			// Generate a GUID for any uploads to be performed.
			string uploadGUID = HttpUtility.UrlEncode(Guid.NewGuid().ToString());
			
			// Build up the client side script (javascript)
			string script = "";
			script += "<script type=\"text/javascript\"><!--\r\n";
			script += "function StartUpload()\r\n";
			script += "{\r\n";
			// The progress bar window opener
			script += "window.open('UploadProgressBar.aspx?UploadID=" + uploadGUID + "', 'UploadProgressBar', 'width=500, height=140, left=150, top=100, location=no, menubar=no, status=no, resizable=no, titlebar=no, toolbar=no, scrollbars=no');\r\n";
			// The self reload code
			script += "document.Form1.action = 'default.aspx?UploadID=" + uploadGUID + "';\r\n";
			script += "document.Form1.submit();\r\n";
			script += "}\r\n";
			script += "// -->\r\n";
			script += "</script>\r\n";

			// Place the script into the page
			RegisterClientScriptBlock("uploadStart", script);

			// Set the onclick event for the submit button
			// to execute the above script
			btnUpload.Attributes.Add("onclick", "StartUpload();");
		}

		private void btnUpload_ServerClick(object sender, System.EventArgs e)
		{
			// Indicate the name of the file which was uploaded.
			Response.Write("File uploaded: " + file1.PostedFile.FileName);

			// Save the uploaded files into the default temporary directory, usually
			// C:\Documents and Settings\Machine Name\ASPNET\Local Settings\Temp
			string destinationPath = Path.Combine(Path.GetTempPath(), "LITUploadExample");
			
			// Ensure that the destination directory exists
			Directory.CreateDirectory(destinationPath);

			// Assemble the destination path for the uploaded file
			string file1Path = Path.Combine(destinationPath, Path.GetFileName(file1.PostedFile.FileName));

			// Delete the destination file if it already exists
			if (File.Exists(file1Path))
				File.Delete(file1Path);

			// Save the file
			try
			{
				if(file1.PostedFile.FileName != "")
					file1.PostedFile.SaveAs(file1Path);
				Response.Write("<br>Saved file into the " + destinationPath + " directory");

			}
			catch (Exception exception)
			{
				Response.Write("<br>Files could not be saved. Exception: " + exception.Message);
			}
		}
	}
}
